<?php

class DispletRetsIdxUsersUpdates extends DispletRetsIdxPlugin{
	public function upgrade_users_to_role_2(){
		$leads = DispletRetsIdxUsers::get_re_search_users();
		if (!empty($leads)) {
			foreach ($leads as $lead) {
				$name = get_user_meta($lead->ID, 'nickname', true);
				$names = DispletRetsIdxUsers::get_first_and_last_name($name);
				if (!empty($names)) {		
					wp_update_user(array(
						'ID' => $lead->ID,
						'display_name' => $names['first_name']
					));
					update_user_meta($lead->ID, 'first_name', $names['first_name']);
					update_user_meta($lead->ID, 'last_name', $names['last_name']);
				}
				$api_user_id = get_user_meta($lead->ID, 'displet_api_user_id', true);
				if (empty($api_user_id)) {
					$api_user_id = DispletRetsIdxUsersApi::create_user($lead->user_email, $names['first_name'], $names['last_name']);
					update_user_meta($lead->ID, 'displet_api_user_id', $api_user_id);
				}
				DispletRetsIdxUsers::send_users_saved_searches_to_api($lead->ID, $api_user_id);
			}
		}
	}

	public function schedule_register_non_api_users_with_api_cron(){
		wp_schedule_single_event(time(), 'displetretsidx_register_non_api_users_with_api_cron');
	}

	public function register_non_api_users_with_api_cron(){
		$users = DispletRetsIdxUsers::get_re_search_users();
		if (!empty($users) && is_array($users)) {
			$i = 1;
			$count = count($users);
			$finished_after = time() + ($count + 1) * 30;
			foreach ($users as $user) {
				if (empty($user->displet_api_user_id)){
					$args = array(
						'user_id' => $user->ID,
						'user_email' => $user->user_email,
						'user_first_name' => $user->first_name,
						'user_last_name' => $user->last_name,
						'viewed_properties' => $user->displet_user_properties,
						'finished_after' => $finished_after
					);
					wp_schedule_single_event(time() + $i * 30, 'displetretsidx_register_non_api_users_with_api_cron_per_user', array($args));
					$i++;
				}
			}
		}
	}

	public function register_non_api_users_with_api_cron_per_user($args){
		$api_user_id = DispletRetsIdxUsersApi::create_user($args['user_email'], $args['user_first_name'], $args['user_last_name']);
		if (!empty($api_user_id)) {
			update_user_meta($args['user_id'], 'displet_api_user_id', $api_user_id);
			DispletRetsIdxUsers::send_users_saved_searches_to_api($args['user_id'], $api_user_id);
			if (!empty($args['viewed_properties'])) {
				$i = 1;
				foreach ($args['viewed_properties'] as $viewed_property) {
					wp_schedule_single_event(time() + $args['finished_after'] + $i * 30, 'displetretsidx_register_non_api_users_with_api_cron_per_property', array($viewed_property['url'], $api_user_id));
				}
			}
		}
	}

	public function register_non_api_users_with_api_cron_per_property($url, $api_user_id){
		$property_id = DispletRetsIdxUsers::get_property_id_from_url($url);
		$model = DispletRetsIdxUrlStructure::create_model(false);
		$model['property_id'] = $property_id;
		DispletRetsIdxPropertyDetails::build_model($model);
		global $displetretsidx_model;
		if (!empty($displetretsidx_model['listings'][0]) && !empty($displetretsidx_model['listings'][0]->id)) {
			wp_schedule_single_event(time(), 'displetretsidx_register_non_api_users_with_api_cron_per_property_at_api', array($api_user_id, $displetretsidx_model['listings'][0]->id));
		}
	}

	public function save_new_meta_values_for_user_searches(){
		$users = DispletRetsIdxUsers::get_re_search_users();
		if (!empty($users)) {
			foreach ($users as $user) {
				if (!empty($user->ID)) {
					wp_schedule_single_event(time() + $delay + $i * 30, 'displetretsidx_save_new_meta_values_for_user_searches_per_user', array($user->ID));
				}
			}
		}
	}

	public function save_new_meta_values_for_user_searches_per_user($user_id){
		$user_properties = get_user_meta($user_id, 'displet_user_properties', true);
		if (!empty($user_properties)) {
			DispletRetsIdxUsers::update_property_view_stats($user_id, $user_properties);
		}
		$user_searches = get_user_meta($user_id, 'displet_user_hashes', true);
		if (!empty($user_searches)) {
			update_user_meta($user_id, 'displet_user_hashes_count', count($user_searches));
		}
		$user_logins = get_user_meta($user_id, 'displet_logins', true);
		if (!empty($user_logins)) {
			update_user_meta($user_id, 'displet_logins_count', count($user_logins));
		}
	}
}
add_action('displetretsidx_register_non_api_users_with_api_cron', array('DispletRetsIdxUsersUpdates', 'register_non_api_users_with_api_cron'));
add_action('displetretsidx_register_non_api_users_with_api_cron_per_user', array('DispletRetsIdxUsersUpdates', 'register_non_api_users_with_api_cron_per_user'), 10, 1);
add_action('displetretsidx_register_non_api_users_with_api_cron_per_property', array('DispletRetsIdxUsersUpdates', 'register_non_api_users_with_api_cron_per_property'), 10, 2);
add_action('displetretsidx_register_non_api_users_with_api_cron_per_property_at_api', array('DispletRetsIdxUsersApi', 'update_user_property_views'), 10, 2);
add_action('displetretsidx_save_new_meta_values_for_user_searches_per_user', array('DispletRetsIdxUsersUpdates', 'save_new_meta_values_for_user_searches_per_user'), 10, 1);

?>